SMS J.A.R.V.I.S.
================

.. image:: https://travis-ci.org/sms-jarvis/sms-jarvis.svg?branch=master
    :target: https://travis-ci.org/sms-jarvis/sms-jarvis

Application to handle SMS requests and redirect them to services based on the provided configuration
